python-libdiscid |release|
==========================

`python-libdiscid` provides Python 3 bindings for :musicbrainz:`libdiscid`.
`libdiscid`'s main purpose is the calculation of
:musicbrainz:`identifiers <Disc ID>` for audio discs to use for the
MusicBrainz_ database.

`python-libdiscid` is released under the :ref:`MIT license <license>`.

Contents
^^^^^^^^

.. toctree::

   installation
   usage
   misc
   api
   changelog
   license

Index
^^^^^

* :ref:`genindex`

.. _MusicBrainz: http://musicbrainz.org
